Tests for homoscedasticity — STAC 0.7 documentation

### Navigation

- index
- next |
- previous |
- STAC 0.7 documentation »

#### Previous topic

scipy.stats.kstest

#### Next topic

scipy.stats.levene

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

# Tests for homoscedasticity

`levene`(*args, **kwds) | Perform Levene test for equal variances.

### Navigation

- index
- next |
- previous |
- STAC 0.7 documentation »

© Copyright 2015, Ismael. Created using Sphinx 1.2.1.